searchData={"items":[{"type":"module","title":"Ecto.ERD.Field","doc":"Field struct\n\nRepresents data of an individual field in `Ecto.ERD.Node`.\n\nFeel free to update fields of this struct in `.ecto_erd.exs` if needed.","ref":"Ecto.ERD.Field.html"},{"type":"type","title":"Ecto.ERD.Field.comment/0","doc":"A field comment.\n\nRendering of comments is supported only by Mermaid format at the moment.","ref":"Ecto.ERD.Field.html#t:comment/0"},{"type":"type","title":"Example - Ecto.ERD.Field.comment/0","doc":"# File: .ecto_erd.exs\n    [\n      map_node: fn\n        %Ecto.ERD.Node{schema_module: schema_module} = node ->\n          update_in(node, [Access.key(:fields), Access.all()], fn field ->\n            # `DocumentationLib` is a fictional module returning documentation about a field\n            case DocumentationLib.doc({schema_module, field})  do\n              nil ->\n                field\n\n              doc ->\n                %{field | comment: doc}\n            end\n          end)\n        end\n    ]","ref":"Ecto.ERD.Field.html#t:comment/0-example"},{"type":"function","title":"Ecto.ERD.Field.new/1","doc":"","ref":"Ecto.ERD.Field.html#new/1"},{"type":"type","title":"Ecto.ERD.Field.t/0","doc":"","ref":"Ecto.ERD.Field.html#t:t/0"},{"type":"module","title":"Ecto.ERD.Node","doc":"Node struct\n\n* If `source` is `nil`, then `schema_module` cannot be `nil` and node describes embedded schema.\n* If `source` is not `nil` and `schema_module` is not `nil`, then node describes regular schema.\n* If `schema_module` is `nil`, then `source` cannot be `nil` and node describes a source (table) which was\nautomatically\ninferred from many-to-many relations.\n* If `cluster` is `nil`, then the node will be rendered outside any cluster..","ref":"Ecto.ERD.Node.html"},{"type":"function","title":"Ecto.ERD.Node.set_cluster/2","doc":"Set a `cluster` for a given `node`.\n\nCluster is a group of nodes which are displayed together.","ref":"Ecto.ERD.Node.html#set_cluster/2"},{"type":"type","title":"Ecto.ERD.Node.t/0","doc":"","ref":"Ecto.ERD.Node.html#t:t/0"},{"type":"task","title":"mix ecto.gen.erd","doc":"A mix task to generate an ERD (Entity Relationship Diagram) in various formats.\n\nSupported formats:\n* [DOT](#module-dot) (default)\n* [PlantUML](#module-plantuml)\n* [DBML](#module-dbml)\n* [QuickDBD](#module-quickdbd)\n* [Mermaid](#module-mermaid)\n\nConfiguration examples and output for a couple of open-source projects can be found in EXAMPLES group of PAGES section.","ref":"Mix.Tasks.Ecto.Gen.Erd.html"},{"type":"task","title":"DOT - mix ecto.gen.erd","doc":"[DOT](https://en.wikipedia.org/wiki/DOT_(graph_description_language)) format is able to represent all available types of entities:\n* schemas\n* embedded schemas\n* schemaless tables (automatically derived from many-to-many relations)\n\nClusters are supported and can be set in `:map_node` option using `Ecto.ERD.Node.set_cluster/2`.\n\nYou should have installed [graphviz](https://graphviz.org/) in order to convert `*.dot` file to image.\n\n```\n$ mix ecto.gen.erd # generates ecto_erd.dot\n$ mix ecto.gen.erd --output-path=ecto_erd.dot\n$ mix ecto.gen.erd && dot -Tpng ecto_erd.dot -o erd.png && xdg-open erd.png\n```","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-dot"},{"type":"task","title":"PlantUML - mix ecto.gen.erd","doc":"[PlantUML](https://plantuml.com) is equal to DOT in number of supported features.\n\nYou should have installed [plantuml](https://plantuml.com/download) in order to convert `*.puml` file to image.\n\n```\n$ mix ecto.gen.erd --output-path=erd.puml\n$ mix ecto.gen.erd --output-path=erd.puml && plantuml erd.puml && xdg-open erd.png\n```\n*Tip: if output image is cropped, you may need to adjust image size with `PLANTUML_LIMIT_SIZE` environment variable.*","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-plantuml"},{"type":"task","title":"DBML - mix ecto.gen.erd","doc":"[DBML](https://www.dbml.org/) format is more limited in number of displayed entity types comparing to DOT and PlantUML, as it is focused on tables only.\nMultiple schemas that use the same table are merged into one table. Embedded schemas, obviously,\ncannot be displayed at all.\n`TableGroup`s are supported and can be set in `:map_node` option using `Ecto.ERD.Node.set_cluster/2`.\n\nThis format is very handy if you use [dbdiagram.io](https://dbdiagram.io) or [dbdocs.io](https://dbdocs.io).\n\n```\n$ mix ecto.gen.erd --output-path=ecto_erd.dbml\n```","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-dbml"},{"type":"task","title":"QuickDBD - mix ecto.gen.erd","doc":"A format that is used by [QuickDBD](https://www.quickdatabasediagrams.com) - a competitor of [dbdiagram.io](https://dbdiagram.io).\nSimilarly to DBML, it is also focused on tables and cannot display embedded schemas. However, this format doesn't support clusters.\n\nIt doesn't have a reserved file extension, but we use `*.qdbd`.\n\n```\n$ mix ecto.gen.erd --output-path=ecto_erd.qdbd\n```","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-quickdbd"},{"type":"task","title":"Mermaid - mix ecto.gen.erd","doc":"[Mermaid](https://mermaid-js.github.io/mermaid/#/entityRelationshipDiagram) is also limited, comparing to [DOT](#module-dot) and [PlantUML](#module-plantuml), and focused on tables only.\nMultiple schemas that use the same table are merged into one table. Embedded schemas, cannot be displayed.\nClusters are not supported.\nThe benefit of this format is that it is [supported by Github](https://github.blog/2022-02-14-include-diagrams-markdown-files-mermaid/).\n```\n$ mix ecto.gen.erd --output-path=ecto_erd.mmd\n```\nIf you have installed [mermaid-cli](https://github.com/mermaid-js/mermaid-cli) locally, the output `*.mmd` file can be\nconverted to image using the following command:\n```\n$ mmdc -i ecto_erd.mmd -o erd.png -w 6000 -H 6000\n```\nDefault `-w` and `-H` values are quite small (`800` and `600` respectively), so it is better to provide bigger values from the very beginning.","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-mermaid"},{"type":"task","title":"Command line options - mix ecto.gen.erd","doc":"* `--output-path` - the path to the output file, defaults to `ecto_erd.dot`. Supported file extensions: `dot`, `puml`, `dbml`, `qdbd`.\n* `--config-path` - the path to the config file, defaults to `.ecto_erd.exs`.","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-command-line-options"},{"type":"task","title":"Configuration file - mix ecto.gen.erd","doc":"When running a `mix ecto.gen.erd` task, it tries to read a configuration file from the `.ecto_erd.exs` file in a current\nworking directory. Configuration file must return a keyword list.","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-configuration-file"},{"type":"task","title":"Options - mix ecto.gen.erd","doc":"* `:fontname` - font name, defaults to `Roboto Mono`. Must be monospaced font if output format is `dot` and more than 1 column is displayed.\nThe option is only supported for `dot` and `puml` files.\n* `:columns` - list of columns which will be displayed for each node (schema/source). Set to `[]` to hide fields completely.\nAvailable columns: `:name` and `:type`. The option is only supported for `dot`, `puml` and `mmd`(`mmd` only allows usage of `[]` and the default value).\nDefault values:\n  * `[:name, :type]` for `dot` and `puml`.\n  * `[:type, :name]` for `mmd`\n* `:map_node` - function which allows to remove the node from the diagram or to move the node to the cluster. Defaults to `Function.identity/1`,\nwhich means that all nodes should be displayed and all of them are outside any cluster.\nUse `Ecto.ERD.Node.set_cluster/2` in this function to set a cluster. Only supported by [DOT](#module-dot), [PlantUML](#module-plantuml)\nand [DBML](#module-dbml).\nIn order to remove the node from diagram, the function must return `nil`.\n* `:otp_app` - an application which will be scanned alongside with dependent applications in order to get a list of Ecto schemas.\nDefaults to `Mix.Project.config()[:app]`. You need to configure this option only if you run a task from the umbrella root.\n\nConfiguration file file with default values for `dot` and `puml` can be represented as follows:\n\n    # .ecto_erd.exs\n    [\n      fontname: \"Roboto Mono\",\n      columns: [:name, :type],\n      map_node: &Function.identity/1,\n      otp_app: Mix.Project.config()[:app]\n    ]","ref":"Mix.Tasks.Ecto.Gen.Erd.html#module-options"},{"type":"extras","title":"changelog.com","doc":"# changelog.com\n\nRepo: `git@github.com:thechangelog/changelog.com.git`","ref":"changelog-com.html"},{"type":"extras","title":"Default - changelog.com","doc":"#### Output\n\n| Format       | Document                                                                                             | Image                                                                                              |\n| ------------ | ---------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------- |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/changelog.com/Default.dbml)      | —                                                                                                  |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/changelog.com/Default.dot)        | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/changelog.com/Default.png)      |\n| **QuickDBD** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/quick_dbd/changelog.com/Default.qdbd) | —                                                                                                  |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/changelog.com/Default.puml)  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/changelog.com/Default.png) |\n| **Mermaid**  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/mermaid/changelog.com/Default.mmd)    | —                                                                                                  |","ref":"changelog-com.html#default"},{"type":"extras","title":"No fields - changelog.com","doc":"#### Output\n\n| Format      | Document                                                                                            | Image                                                                                           |\n| ----------- | --------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------- |\n| **DOT**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/changelog.com/No-fields.dot)     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/changelog.com/No-fields.png) |\n| **Mermaid** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/mermaid/changelog.com/No-fields.mmd) | —                                                                                               |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\n[\n  columns: []\n]\n\n```","ref":"changelog-com.html#no-fields"},{"type":"extras","title":"Clusters - changelog.com","doc":"#### Output\n\n| Format       | Document                                                                                             | Image                                                                                               |\n| ------------ | ---------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------- |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/changelog.com/Clusters.dbml)     | —                                                                                                   |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/changelog.com/Clusters.dot)       | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/changelog.com/Clusters.png)      |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/changelog.com/Clusters.puml) | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/changelog.com/Clusters.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  map_node: fn\n    %Node{schema_module: schema_module} = node ->\n      cluster_name =\n        cond do\n          schema_module in [\n            Changelog.Episode,\n            Changelog.EpisodeChapter,\n            Changelog.EpisodeGuest,\n            Changelog.EpisodeHost,\n            Changelog.EpisodeRequest,\n            Changelog.EpisodeSponsor,\n            Changelog.EpisodeStat,\n            Changelog.EpisodeTopic\n          ] ->\n            \"EPISODE\"\n\n          schema_module in [Changelog.Post, Changelog.PostTopic] ->\n            \"POST\"\n\n          schema_module in [Changelog.Podcast, Changelog.PodcastHost, Changelog.PodcastTopic] ->\n            \"PODCAST\"\n\n          schema_module in [Changelog.Sponsor, Changelog.SponsorRep] ->\n            \"SPONSOR\"\n\n          schema_module in [Changelog.Person, Changelog.Person.Settings] ->\n            \"PERSON\"\n\n          schema_module in [\n              Changelog.EpisodeNewsItem,\n              Changelog.NewsAd,\n              Changelog.NewsIssue,\n              Changelog.NewsIssueAd,\n              Changelog.NewsIssueItem,\n              Changelog.NewsItem,\n              Changelog.NewsItemComment,\n              Changelog.NewsItemTopic,\n              Changelog.NewsQueue,\n              Changelog.NewsSource,\n              Changelog.NewsSponsorship,\n              Changelog.PostNewsItem\n            ] -> \"NEWS\"\n\n          true ->\n            nil\n        end\n\n      Node.set_cluster(node, cluster_name)\n  end\n]\n\n```","ref":"changelog-com.html#clusters"},{"type":"extras","title":"hexpm","doc":"# hexpm\n\nRepo: `git@github.com:hexpm/hexpm.git`","ref":"hexpm.html"},{"type":"extras","title":"Default - hexpm","doc":"#### Output\n\n| Format       | Document                                                                                     | Image                                                                                      |\n| ------------ | -------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------ |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/hexpm/Default.dbml)      | —                                                                                          |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Default.dot)        | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Default.png)      |\n| **QuickDBD** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/quick_dbd/hexpm/Default.qdbd) | —                                                                                          |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Default.puml)  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Default.png) |\n| **Mermaid**  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/mermaid/hexpm/Default.mmd)    | —                                                                                          |","ref":"hexpm.html#default"},{"type":"extras","title":"No fields - hexpm","doc":"#### Output\n\n| Format      | Document                                                                                    | Image                                                                                   |\n| ----------- | ------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------- |\n| **DOT**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/No-fields.dot)     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/No-fields.png) |\n| **Mermaid** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/mermaid/hexpm/No-fields.mmd) | —                                                                                       |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\n[\n  columns: []\n]\n\n```","ref":"hexpm.html#no-fields"},{"type":"extras","title":"Contexts as clusters - hexpm","doc":"#### Output\n\n| Format       | Document                                                                                                 | Image                                                                                                   |\n| ------------ | -------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------- |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/hexpm/Contexts-as-clusters.dbml)     | —                                                                                                       |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Contexts-as-clusters.dot)       | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Contexts-as-clusters.png)      |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Contexts-as-clusters.puml) | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Contexts-as-clusters.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  map_node: fn\n    %Node{schema_module: schema_module} = node ->\n      case Module.split(schema_module) do\n        [_] -> node\n        [namespace, _] -> node |> Node.set_cluster(namespace)\n        parts -> node |> Node.set_cluster(parts |> Enum.take(2) |> Enum.join(\".\"))\n      end\n  end\n]\n\n```","ref":"hexpm.html#contexts-as-clusters"},{"type":"extras","title":"Contexts as clusters (no fields) - hexpm","doc":"#### Output\n\n| Format       | Document                                                                                                           | Image                                                                                                             |\n| ------------ | ------------------------------------------------------------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------- |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Contexts-as-clusters-no-fields.dot)       | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Contexts-as-clusters-no-fields.png)      |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Contexts-as-clusters-no-fields.puml) | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Contexts-as-clusters-no-fields.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  columns: [],\n  map_node: fn\n    %Node{schema_module: schema_module} = node ->\n      case Module.split(schema_module) do\n        [_] -> node\n        [namespace, _] -> node |> Node.set_cluster(namespace)\n        parts -> node |> Node.set_cluster(parts |> Enum.take(2) |> Enum.join(\".\"))\n      end\n  end\n]\n\n```","ref":"hexpm.html#contexts-as-clusters-no-fields"},{"type":"extras","title":"Only selected cluster (Accounts context) - hexpm","doc":"#### Output\n\n| Format       | Document                                                                                                                    | Image                                                                                                                     |\n| ------------ | --------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------- |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/hexpm/Only-selected-cluster-Accounts-context.dbml)      | —                                                                                                                         |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Only-selected-cluster-Accounts-context.dot)        | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Only-selected-cluster-Accounts-context.png)      |\n| **QuickDBD** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/quick_dbd/hexpm/Only-selected-cluster-Accounts-context.qdbd) | —                                                                                                                         |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Only-selected-cluster-Accounts-context.puml)  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Only-selected-cluster-Accounts-context.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  map_node: fn\n    %Node{schema_module: schema_module} = node ->\n      cluster_name = schema_module |> Module.split() |> Enum.take(2) |> Enum.join(\".\")\n      case cluster_name do\n        \"Hexpm.Accounts\" -> node |> Node.set_cluster(cluster_name)\n        _ -> nil\n      end\n  end\n]\n\n```","ref":"hexpm.html#only-selected-cluster-accounts-context"},{"type":"extras","title":"Only embedded schemas - hexpm","doc":"#### Output\n\n| Format       | Document                                                                                                  | Image                                                                                                    |\n| ------------ | --------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Only-embedded-schemas.dot)       | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/hexpm/Only-embedded-schemas.png)      |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Only-embedded-schemas.puml) | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/hexpm/Only-embedded-schemas.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  map_node: fn\n    %Node{source: nil} = node -> node\n    _ -> nil\n  end\n]\n\n```","ref":"hexpm.html#only-embedded-schemas"},{"type":"extras","title":"plausible-analytics","doc":"# plausible-analytics\n\nRepo: `git@github.com:plausible/analytics.git`","ref":"plausible-analytics.html"},{"type":"extras","title":"Default - plausible-analytics","doc":"#### Output\n\n| Format       | Document                                                                                                   | Image                                                                                                    |\n| ------------ | ---------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/plausible-analytics/Default.dbml)      | —                                                                                                        |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/Default.dot)        | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/Default.png)      |\n| **QuickDBD** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/quick_dbd/plausible-analytics/Default.qdbd) | —                                                                                                        |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/plausible-analytics/Default.puml)  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/plausible-analytics/Default.png) |\n| **Mermaid**  | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/mermaid/plausible-analytics/Default.mmd)    | —                                                                                                        |","ref":"plausible-analytics.html#default"},{"type":"extras","title":"No fields - plausible-analytics","doc":"#### Output\n\n| Format      | Document                                                                                                  | Image                                                                                                 |\n| ----------- | --------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------- |\n| **DOT**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/No-fields.dot)     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/No-fields.png) |\n| **Mermaid** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/mermaid/plausible-analytics/No-fields.mmd) | —                                                                                                     |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\n[\n  columns: []\n]\n\n```","ref":"plausible-analytics.html#no-fields"},{"type":"extras","title":"Contexts as clusters - plausible-analytics","doc":"#### Output\n\n| Format       | Document                                                                                                               | Image                                                                                                                 |\n| ------------ | ---------------------------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------- |\n| **DBML**     | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dbml/plausible-analytics/Contexts-as-clusters.dbml)     | —                                                                                                                     |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/Contexts-as-clusters.dot)       | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/Contexts-as-clusters.png)      |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/plausible-analytics/Contexts-as-clusters.puml) | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/plausible-analytics/Contexts-as-clusters.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  map_node: fn\n    %Node{schema_module: schema_module} = node ->\n      case Module.split(schema_module) do\n        [_] -> node\n        [namespace, _] -> node |> Node.set_cluster(namespace)\n        parts -> node |> Node.set_cluster(parts |> Enum.take(2) |> Enum.join(\".\"))\n      end\n  end\n]\n\n```","ref":"plausible-analytics.html#contexts-as-clusters"},{"type":"extras","title":"Contexts as clusters (no fields) - plausible-analytics","doc":"#### Output\n\n| Format       | Document                                                                                                                         | Image                                                                                                                           |\n| ------------ | -------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |\n| **DOT**      | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/Contexts-as-clusters-no-fields.dot)       | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/dot/plausible-analytics/Contexts-as-clusters-no-fields.png)      |\n| **PlantUML** | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/plausible-analytics/Contexts-as-clusters-no-fields.puml) | [View](https://github.com/fuelen/ecto_erd/blob/v0.6.2/examples/plantuml/plausible-analytics/Contexts-as-clusters-no-fields.png) |\n\n\n#### Config file\n\n```elixir\n# .ecto_erd.exs\nalias Ecto.ERD.Node\n\n[\n  columns: [],\n  map_node: fn\n    %Node{schema_module: schema_module} = node ->\n      case Module.split(schema_module) do\n        [_] -> node\n        [namespace, _] -> node |> Node.set_cluster(namespace)\n        parts -> node |> Node.set_cluster(parts |> Enum.take(2) |> Enum.join(\".\"))\n      end\n  end\n]\n\n```","ref":"plausible-analytics.html#contexts-as-clusters-no-fields"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}